Module blaxel.core.client.models.region
=======================================

Classes
-------

`Region(allowed: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, continent: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, country: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, info_generation: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, location: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Region
    
    Attributes:
        allowed (Union[Unset, str]): Region display name
        continent (Union[Unset, str]): Region display name
        country (Union[Unset, str]): Region display name
        info_generation (Union[Unset, str]): Region display name
        location (Union[Unset, str]): Region display name
        name (Union[Unset, str]): Region name
    
    Method generated by attrs for class Region.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `allowed: blaxel.core.client.types.Unset | str`
    :

    `continent: blaxel.core.client.types.Unset | str`
    :

    `country: blaxel.core.client.types.Unset | str`
    :

    `info_generation: blaxel.core.client.types.Unset | str`
    :

    `location: blaxel.core.client.types.Unset | str`
    :

    `name: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :